@@ -1,6 +1,4 @@
 /*
- *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -16,53 +14,17 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/*
- *  draw.c
- *
- *  Drawing routines for xnec2c
- */
-
 #include "draw.h"
 #include "shared.h"
 
 /*-----------------------------------------------------------------------*/
 
-/* Set_Gdk_Segment()
- *
- *  Calculates window x,y co-ordinates of a GdkSegment for
- *  drawing on Screen. Input data is a line in the xyz frame
- */
-void
-Set_Gdk_Segment(
-	GdkSegment *segm,
-	projection_parameters_t *params,
-	double x1, double y1, double z1,
-	double x2, double y2, double z2 )
-{
-  double x, y;
-
-  /* Project end 1 of seg in xyz frame to screen frame */
-  Project_on_Screen( params, x1, y1, z1, &x, &y );
-  segm->x1 = (gint)(params->x_center + x*params->xy_scale);
-  segm->y1 = params->pixmap_height -
-	(gint)(params->y_center + y*params->xy_scale);
-
-  /* Project end 2 of seg in xyz frame to screen frame */
-  Project_on_Screen( params, x2, y2, z2, &x, &y );
-  segm->x2 = (gint)(params->x_center + x*params->xy_scale);
-  segm->y2 = params->pixmap_height -
-	(gint)(params->y_center + y*params->xy_scale);
-
-} /* Set_Gdk_Segment() */
-
-/*-----------------------------------------------------------------------*/
-
 /*  Project_on_Screen()
  *
  *  Projects a point in the x,y,z co-ordinate
  *  frame of NEC2 to the x,y frame of the Screen
  */
-void
+  static void
 Project_on_Screen(
 	projection_parameters_t *params,
 	double x, double y, double z,
@@ -76,60 +38,88 @@ Project_on_Screen(
 
 /*-----------------------------------------------------------------------*/
 
+/* Set_Gdk_Segment()
+ *
+ *  Calculates window x,y co-ordinates of a Segment_t for
+ *  drawing on Screen. Input data is a line in the xyz frame
+ */
+  void
+Set_Gdk_Segment(
+	Segment_t *segm,
+	projection_parameters_t *params,
+	double x1, double y1, double z1,
+	double x2, double y2, double z2 )
+{
+  double x, y;
+
+  /* Project end 1 of seg in xyz frame to screen frame */
+  Project_on_Screen( params, x1, y1, z1, &x, &y );
+  segm->x1 = (gint)(params->x_center + params->dx_center + x*params->xy_scale);
+  segm->y1 = params->height -
+	(gint)(params->y_center + params->dy_center + y*params->xy_scale);
+
+  /* Project end 2 of seg in xyz frame to screen frame */
+  Project_on_Screen( params, x2, y2, z2, &x, &y );
+  segm->x2 = (gint)(params->x_center + params->dx_center + x*params->xy_scale);
+  segm->y2 = params->height -
+	(gint)(params->y_center + params->dy_center + y*params->xy_scale);
+
+} /* Set_Gdk_Segment() */
+
+/*-----------------------------------------------------------------------*/
+
 /*  Project_XYZ_Axes()
  *
- *  Sets GdkSegment data to project xyz axes on Screen
+ *  Sets Segment_t data to project xyz axes on Screen
  */
-void
+  static void
 Project_XYZ_Axes(
-	GdkPixmap *pixmap,
+	cairo_t *cr,
 	projection_parameters_t *params,
-	GdkSegment *segment )
+	Segment_t *segment )
 {
   double x, y;
   PangoLayout *layout;
-  GdkSegment *segm = segment;
+  Segment_t *segm = segment;
 
   /* cairo context */
-  cairo_t *cr = gdk_cairo_create( pixmap );
   cairo_set_source_rgb( cr, WHITE );
 
-  layout =
-	gtk_widget_create_pango_layout( structure_drawingarea, "x" );
+  layout = gtk_widget_create_pango_layout( structure_drawingarea, "x" );
 
-  segm->x1 = (gint)params->x_center;
-  segm->y1 = params->pixmap_height - (gint)(params->y_center);
+  segm->x1 = (gint)( params->x_center + params->dx_center );
+  segm->y1 = params->height - (gint)( params->y_center + params->dy_center );
   Project_on_Screen( params, params->r_max, 0.0, 0.0, &x, &y );
-  segm->x2 = (gint)(params->x_center + x*params->xy_scale);
-  segm->y2 = params->pixmap_height -
-	(gint)(params->y_center + y*params->xy_scale);
+  segm->x2 = (gint)(params->x_center + params->dx_center + x*params->xy_scale);
+  segm->y2 = params->height -
+	(gint)(params->y_center + params->dy_center + y*params->xy_scale);
   cairo_move_to( cr, (double)segm->x2, (double)segm->y2 );
   pango_cairo_show_layout( cr, layout );
 
   segm++;
-  segm->x1 = (gint)params->x_center;
-  segm->y1 = params->pixmap_height - (gint)params->y_center;
+  segm->x1 = (gint)( params->x_center + params->dx_center );
+  segm->y1 = params->height - (gint)( params->y_center + params->dy_center );
   Project_on_Screen( params, 0.0, params->r_max, 0.0, &x, &y );
-  segm->x2 = (gint)(params->x_center + x*params->xy_scale);
-  segm->y2 = params->pixmap_height -
-	(gint)(params->y_center + y*params->xy_scale);
+  segm->x2 = (gint)(params->x_center + params->dx_center + x*params->xy_scale);
+  segm->y2 = params->height -
+	(gint)(params->y_center + params->dy_center + y*params->xy_scale);
   pango_layout_set_text( layout, "y", -1 );
   cairo_move_to( cr, (double)segm->x2, (double)segm->y2 );
   pango_cairo_show_layout( cr, layout );
 
   segm++;
-  segm->x1 = (gint)params->x_center;
-  segm->y1 = params->pixmap_height - (gint)params->y_center;
+  segm->x1 = (gint)( params->x_center + params->dx_center );
+  segm->y1 = params->height - (gint)( params->y_center + params->dy_center );
   Project_on_Screen( params, 0.0, 0.0, params->r_max, &x, &y );
-  segm->x2 = (gint)(params->x_center + x*params->xy_scale);
-  segm->y2 = params->pixmap_height -
-	(gint)(params->y_center + y*params->xy_scale);
+  segm->x2 = (gint)(params->x_center + params->dx_center + x*params->xy_scale);
+  segm->y2 = params->height -
+	(gint)(params->y_center + params->dy_center + y*params->xy_scale);
   pango_layout_set_text( layout, " z", -1 );
   cairo_move_to( cr, (double)segm->x2, (double)segm->y2 );
   pango_cairo_show_layout( cr, layout );
+
   g_object_unref( layout );
 
-  cairo_destroy( cr );
 } /* Project_XYZ_Axes() */
 
 /*-----------------------------------------------------------------------*/
@@ -139,40 +129,36 @@ Project_XYZ_Axes(
  *  Draws the xyz axes to Screen
  */
   void
-Draw_XYZ_Axes( GdkPixmap *pixmap, projection_parameters_t params )
+Draw_XYZ_Axes( cairo_t *cr, projection_parameters_t params )
 {
-  static GdkSegment seg[3];
-  cairo_t *cr = gdk_cairo_create( pixmap );
-  cairo_set_source_rgb( cr, WHITE );
+  static Segment_t seg[3];
 
   /* Calcualte Screen co-ordinates of xyz axes */
-  Project_XYZ_Axes( pixmap, &params, seg );
+  Project_XYZ_Axes( cr, &params, seg );
 
   /* Draw xyz axes */
   Cairo_Draw_Segments( cr, seg, 3 );
 
-  cairo_destroy( cr );
 } /* Draw_XYZ_Axes() */
 
 /*-----------------------------------------------------------------------*/
 
 /*  New_Projection_Parameters()
  *
- *  Calculates values for some projection parameters when
- *  a new backing pixmap is created after window resize or
- *  new wire or patch data is entered.
+ *  Calculates values for some projection parameters after
+ *  a window is resized or new wire or patch data entered.
  */
-void
+  void
 New_Projection_Parameters(
 	int width, int height,
 	projection_parameters_t *params )
 {
+  /* Half the size of drawing area */
   double size2;
-
   if( width < height )
-	size2 = (double)width/2.0;
+	size2 = (double)width / 2.0;
   else
-	size2 = (double)height/2.0;
+	size2 = (double)height / 2.0;
 
   /* This defines the center of the drawing areas. For the x co-ordinate
    * half the size of the drawing area is right (for widths of odd number
@@ -180,8 +166,8 @@ New_Projection_Parameters(
    * side of center). But for the y co-ordinate we need to round up as
    * y is from the top down and the y co-ordinate of center is calculated
    * from height - y_center and this leads to a 1-pixel error */
-  params->x_center = size2;
-  params->y_center = size2 + 0.5;
+  params->x_center = (double)width / 2.0;
+  params->y_center = (double)height / 2.0 + 0.5;
 
   if( params->r_max == 0.0 )
 	params->xy_scale1 = 1.0;
@@ -189,8 +175,8 @@ New_Projection_Parameters(
 	params->xy_scale1 = size2 / params->r_max;
   params->xy_scale = params->xy_scale1 * params->xy_zoom;
 
-  params->pixmap_width  = width;
-  params->pixmap_height = height;
+  params->width  = width;
+  params->height = height;
 
 } /* New_Projection_Parameters() */
 
@@ -275,7 +261,7 @@ Cairo_Draw_Polygon( cairo_t* cr, GdkPoint *points, int npoints )
  * Draws a number of line segments
  */
   void
-Cairo_Draw_Segments( cairo_t *cr, GdkSegment *segm, int nseg )
+Cairo_Draw_Segments( cairo_t *cr, Segment_t *segm, int nseg )
 {
   int idx;
 
@@ -285,6 +271,7 @@ Cairo_Draw_Segments( cairo_t *cr, GdkSegment *segm, int nseg )
 	cairo_line_to( cr, (double)segm[idx].x2, (double)segm[idx].y2 );
   }
   cairo_stroke( cr );
+
 } /* Cairo_Draw_Segments() */
 
 /*-----------------------------------------------------------------------*/
@@ -299,6 +286,7 @@ Cairo_Draw_Line( cairo_t *cr, int x1, int y1, int x2, int y2 )
   cairo_move_to( cr, (double)x1, (double)y1 );
   cairo_line_to( cr, (double)x2, (double)y2 );
   cairo_stroke( cr );
+
 } /* Cairo_Draw_Line() */
 
 /*-----------------------------------------------------------------------*/
@@ -316,6 +304,7 @@ Cairo_Draw_Lines( cairo_t *cr, GdkPoint *points, int npoints )
   for( idx = 1; idx < npoints; idx++ )
 	cairo_line_to( cr, (double)points[idx].x, (double)points[idx].y );
   cairo_stroke( cr );
+
 } /* Cairo_Draw_Line() */
 
 /*-----------------------------------------------------------------------*/
