@@ -1,6 +1,4 @@
 /*
- *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -16,12 +14,8 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/* misc.c
- *
- * Miscellaneous support functions for xnec2c.c
- */
-
 #include "utils.h"
+#include "shared.h"
 
 /*------------------------------------------------------------------------*/
 
@@ -30,13 +24,14 @@
  *  Prints usage information
  */
 
-void usage(void)
+  void
+usage(void)
 {
   fprintf( stderr,
-	  _("Usage: xnec2c <input-file-name>\n"\
-		"              [-i <input-file-name>]\n"\
-		"              [-j <number of processors in SMP machine>]\n"\
-		"              [-h: print this usage information and exit]\n"\
+	  _("Usage: xnec2c <input-file-name>\n"
+		"              [-i <input-file-name>]\n"
+		"              [-j <number of processors in SMP machine>]\n"
+		"              [-h: print this usage information and exit]\n"
 		"              [-v: print xnec2c version number and exit]\n") );
 
 } /* end of usage() */
@@ -45,8 +40,10 @@ void usage(void)
 
 /* Does the STOP function of fortran but with a warning dialog */
   int
-stop( char *mesg, int err )
+Stop( char *mesg, int err )
 {
+  GtkBuilder *builder;
+
   /* For child processes */
   if( CHILD )
   {
@@ -54,8 +51,7 @@ stop( char *mesg, int err )
 	if( err )
 	{
 	  fprintf( stderr,
-		  _("xnec2c: fatal: child process %d exiting\n"),
-		  num_child_procs );
+		  _("xnec2c: fatal: child process %d exiting\n"), num_child_procs );
 	  _exit(-1);
 	}
 	else return( err );
@@ -64,15 +60,20 @@ stop( char *mesg, int err )
 
   /* Stop operation */
   Stop_Frequency_Loop();
-  error_dialog = create_error_dialog();
-  gtk_label_set_text( GTK_LABEL(
-		lookup_widget(error_dialog, "error_label")), mesg );
 
-  /* Hide ok button according to error */
-  if( err == TRUE )
-	gtk_widget_hide( lookup_widget(
-		  error_dialog, "error_okbutton") );
-  gtk_widget_show( error_dialog );
+  /* Create error dialog */
+  if( !error_dialog )
+  {
+	error_dialog = create_error_dialog( &builder );
+	gtk_label_set_text( GTK_LABEL(
+		  Builder_Get_Object(builder, "error_label")), mesg );
+
+	/* Hide ok button according to error */
+	if( err == TRUE )
+	  gtk_widget_hide( Builder_Get_Object(builder, "error_okbutton") );
+	gtk_widget_show( error_dialog );
+	g_object_unref( builder );
+  }
 
   /* Loop over usleep till user decides what to do */
   /* Could not think of another way to do this :-( */
@@ -87,7 +88,7 @@ stop( char *mesg, int err )
   }
 
   return( err );
-} /* stop */
+} /* Stop() */
 
 /*------------------------------------------------------------------*/
 
@@ -96,12 +97,16 @@ Nec2_Save_Warn( const gchar *mesg )
 {
   if( isFlagSet(FREQ_LOOP_RUNNING) )
   {
-	error_dialog = create_error_dialog();
-	gtk_label_set_text( GTK_LABEL(
-		  lookup_widget(error_dialog, "error_label")), mesg );
-	gtk_widget_hide( lookup_widget(
-		  error_dialog, "error_stopbutton") );
-	gtk_widget_show( error_dialog );
+	GtkBuilder *builder;
+	if( !error_dialog )
+	{
+	  error_dialog = create_error_dialog( &builder );
+	  gtk_label_set_text( GTK_LABEL(
+			Builder_Get_Object(builder, "error_label")), mesg );
+	  gtk_widget_hide( Builder_Get_Object(builder, "error_stopbutton") );
+	  gtk_widget_show( error_dialog );
+	  g_object_unref( builder );
+	}
 
 	/* Loop over usleep till user decides what to do */
 	/* Could not think of another way to do this :-( */
@@ -130,7 +135,8 @@ Nec2_Save_Warn( const gchar *mesg )
  *  EOF is returned.
  */
 
-int Load_Line( char *buff, FILE *pfile )
+  int
+Load_Line( char *buff, FILE *pfile )
 {
   int
 	num_chr, /* number of characters read, excluding lf/cr */
@@ -183,12 +189,6 @@ int Load_Line( char *buff, FILE *pfile )
 
   } /* end of while( num_chr < max_chr ) */
 
-  /* Capitalize first two characters (mnemonics) */
-  if( (buff[0] > 0x60) && (buff[0] < 0x79) )
-	buff[0] = (char)toupper( (int)buff[1] );
-  if( (buff[1] > 0x60) && (buff[1] < 0x79) )
-	buff[1] = (char)toupper( (int)buff[1] );
-
   /* terminate buffer as a string */
   buff[num_chr] = '\0';
 
@@ -199,44 +199,47 @@ int Load_Line( char *buff, FILE *pfile )
 
 /***  Memory allocation/freeing utils ***/
 static size_t cnt = 0; /* Total allocation */
-void mem_alloc( void **ptr, size_t req, gchar *str )
+  void
+mem_alloc( void **ptr, size_t req, gchar *str )
 {
-  gchar mesg[100];
+  gchar mesg[MESG_SIZE];
 
   free_ptr( ptr );
   *ptr = malloc( req );
   cnt += req;
   if( *ptr == NULL )
   {
-	snprintf( mesg, 99, _("Memory allocation denied %s\n"), str );
-	mesg[99] = '\0';
+	snprintf( mesg, sizeof(mesg),
+		_("Memory allocation denied %s\n"), str );
 	fprintf( stderr, "%s: Total memory request %ld\n", mesg, cnt );
-	stop( mesg, ERR_STOP );
+	Stop( mesg, ERR_STOP );
   }
 
 } /* End of mem_alloc() */
 
 /*------------------------------------------------------------------------*/
 
-void mem_realloc( void **ptr, size_t req, gchar *str )
+  void
+mem_realloc( void **ptr, size_t req, gchar *str )
 {
-  gchar mesg[100];
+  gchar mesg[MESG_SIZE];
 
   *ptr = realloc( *ptr, req );
   cnt += req;
   if( *ptr == NULL )
   {
-	snprintf( mesg, 99, _("Memory re-allocation denied %s\n"), str );
-	mesg[99] = '\0';
+	snprintf( mesg, sizeof(mesg),
+		_("Memory re-allocation denied %s\n"), str );
 	fprintf( stderr, "%s: Total memory request %ld\n", mesg, cnt );
-	stop( mesg, ERR_STOP );
+	Stop( mesg, ERR_STOP );
   }
 
 } /* End of mem_realloc() */
 
 /*------------------------------------------------------------------------*/
 
-void free_ptr( void **ptr )
+  void
+free_ptr( void **ptr )
 {
   if( *ptr != NULL )
 	free( *ptr );
@@ -253,22 +256,18 @@ void free_ptr( void **ptr )
   gboolean
 Open_File( FILE **fp, char *fname, const char *mode )
 {
-  /* Abort if file name is blank */
-  if( strlen(infile) == 0 ) return( TRUE );
-
   /* Close file path if open */
   Close_File( fp );
   if( (*fp = fopen(fname, mode)) == NULL )
   {
-	char mesg[110];
-	snprintf( mesg, 109,
+	char mesg[MESG_SIZE];
+	snprintf( mesg, sizeof(mesg),
 		_("xnec2c: %s: Failed to open file\n"), fname );
-	mesg[109] = '\0';
-	stop( mesg, ERR_STOP );
+	Stop( mesg, ERR_STOP );
 	return( FALSE );
   }
 
-  return(TRUE);
+  return( TRUE );
 } /* Open_File() */
 
 /*------------------------------------------------------------------------*/
@@ -280,8 +279,8 @@ Open_File( FILE **fp, char *fname, const char *mode )
   void
 Close_File( FILE **fp )
 {
-  if( *fp != NULL )
-	fclose( *fp );
+  sync();
+  if( *fp != NULL ) fclose( *fp );
   *fp = NULL;
 
 } /* Close_File() */
@@ -297,8 +296,7 @@ Display_Fstep( GtkEntry *entry, int fstep )
 {
   char str[4];
 
-  snprintf( str, 4, "%3d", fstep );
-  str[3] = '\0';
+  snprintf( str, sizeof(str), "%3d", fstep );
   gtk_entry_set_text( entry, str );
 }
 
@@ -390,7 +388,6 @@ Strlcpy( char *dest, const char *src, size_t n )
  * string is null terminated by copying only n-1 chars to leave room
  * for the terminating char. n would normally be the sizeof(dest)
  * string but copying will not go beyond the terminating null of src
-
  */
   void
 Strlcat( char *dest, const char *src, size_t n )
@@ -400,10 +397,11 @@ Strlcat( char *dest, const char *src, size_t n )
   int ids = 0; /* src  index */
 
   /* Find terminating null of dest */
-  while( (ch != '\0') )
+  while( (n > 0) && (ch != '\0') )
   {
 	idd++;
 	ch = dest[idd];
+	n--; /* Count remaining char's in dest */
   }
 
   /* Copy n-1 chars to leave room for terminating null */
@@ -430,12 +428,11 @@ Strlcat( char *dest, const char *src, size_t n )
  * Replaces strtod() to take into account the
  * locale-dependent decimal point character
  */
-double Strtod( const char *nptr, char **endptr )
+double Strtod( char *nptr, char **endptr )
 {
   int idx;
   size_t len;
   double d = 0.0;
-  char *s;
   static gboolean first_call = TRUE;
   static char dp = '.';
 
@@ -457,11 +454,37 @@ double Strtod( const char *nptr, char **endptr )
 	  break;
 
   /* If a decimal point character is found, replace */
-  s = (char *)nptr;
-  if( idx < (int)len ) s[idx] = dp;
-  d = strtod( s, endptr );
+  if( idx < (int)len ) nptr[idx] = dp;
+  d = strtod( (const char *)nptr, endptr );
 
   return( d );
 } /* End of Strtod() */
 
 /*------------------------------------------------------------------*/
+
+/* Get_Dirname()
+ *
+ * Gets the directory name from a file path
+ * including the end / and returns in dirname
+ */
+  void
+Get_Dirname( char *fpath, char *dirname, int *fname_idx )
+{
+  int idx, len;
+
+  /* Get the dirname of input file to use as working directory */
+  len = (int)strlen( fpath );
+  for( idx = len; idx > 0; idx-- )
+	if( fpath[idx] == '/' )
+	  break;
+
+  /* Include end / in directory name */
+  if( dirname ) Strlcpy( dirname, fpath, (size_t)(idx+2) );
+
+  /* Return file name if pointer given */
+  if( fname_idx ) *fname_idx = idx + 1;
+
+} /* Get_Dirname() */
+
+/*------------------------------------------------------------------*/
+
