@@ -1,6 +1,4 @@
 /*
- *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -19,11 +17,8 @@
 #ifndef	UTILS_H
 #define	UTILS_H		1
 
+#include <locale.h>
 #include "common.h"
-#include "interface.h"
-#include "support.h"
-#include "shared.h"
-#include <ctype.h>
 
 /* Carriage return and line feed */
 #define	CR	0x0d
